get.unified.concepts: Finding all concepts used.
Description
get.unified.concepts identifies the common superset of concepts that is used by the maps of a conceptmaps object.
Usage
get.unified.concepts(maps)
Value
A vector of strings of each concepts that appears in at least one of the maps of maps.